==> qt-creator-opensource-src-3.2.0.tar.gz: qt-creator-opensource-src-3.2.0/src/plugins/clangcodemodel/clangmodelmanagersupport.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef CLANGCODEMODEL_INTERNAL_CLANGMODELMANAGERSUPPORT_H
#define CLANGCODEMODEL_INTERNAL_CLANGMODELMANAGERSUPPORT_H

#include <cpptools/cppmodelmanagersupport.h>

#include <QScopedPointer>

namespace ClangCodeModel {
namespace Internal {

class FastIndexer;

class ModelManagerSupport: public CppTools::ModelManagerSupport
{
    Q_DISABLE_COPY(ModelManagerSupport)

public:
    ModelManagerSupport(FastIndexer *fastIndexer);
    virtual ~ModelManagerSupport();

    virtual QString id() const;
    virtual QString displayName() const;

    virtual CppTools::CppCompletionAssistProvider *completionAssistProvider();
    virtual CppTools::CppHighlightingSupport *highlightingSupport(
            TextEditor::BaseTextDocument *baseTextDocument);

private:
    QScopedPointer<CppTools::CppCompletionAssistProvider> m_completionAssistProvider;
    FastIndexer *m_fastIndexer;
};

} // namespace Internal
} // namespace ClangCodeModel

#endif // CLANGCODEMODEL_INTERNAL_CLANGMODELMANAGERSUPPORT_H

==> qt-creator-opensource-src-3.3.0.tar.gz: qt-creator-opensource-src-3.3.0/src/plugins/clangcodemodel/clangmodelmanagersupport.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef CLANGCODEMODEL_INTERNAL_CLANGMODELMANAGERSUPPORT_H
#define CLANGCODEMODEL_INTERNAL_CLANGMODELMANAGERSUPPORT_H

#include <cpptools/cppmodelmanagersupport.h>

#include <QScopedPointer>

namespace ClangCodeModel {
namespace Internal {

class ModelManagerSupport: public CppTools::ModelManagerSupport
{
    Q_DISABLE_COPY(ModelManagerSupport)

public:
    ModelManagerSupport();
    virtual ~ModelManagerSupport();

    virtual QString id() const;
    virtual QString displayName() const;

    virtual CppTools::CppCompletionAssistProvider *completionAssistProvider();
    virtual CppTools::BaseEditorDocumentProcessor *editorDocumentProcessor(
                TextEditor::TextDocument *baseTextDocument);

private:
    QScopedPointer<CppTools::CppCompletionAssistProvider> m_completionAssistProvider;
};

} // namespace Internal
} // namespace ClangCodeModel

#endif // CLANGCODEMODEL_INTERNAL_CLANGMODELMANAGERSUPPORT_H
